@@ -10,6 +10,7 @@
 ######################################################################
 
 import argparse
+import atexit
 import hashlib
 import json
 import os.path
@@ -24,7 +25,7 @@ import threading
 
 import pytest
 
-from b2sdk.utils import fix_windows_path_limit
+from b2sdk.v1 import B2Api, InMemoryAccountInfo, InMemoryCache, fix_windows_path_limit
 
 
 def parse_args(tests):
@@ -111,7 +112,8 @@ class StringReader(object):
 
 def remove_warnings(text):
     return os.linesep.join(
-        line for line in text.split(os.linesep) if 'DeprecationWarning' not in line
+        line for line in text.split(os.linesep)
+        if 'DeprecationWarning' not in line and 'UserWarning' not in line
     )
 
 
@@ -181,17 +183,51 @@ def print_output(status, stdout, stderr):
     print()
 
 
-class CommandLine(object):
+class Api:
+    def __init__(self, account_id, application_key, bucket_name_prefix):
+        self.account_id = account_id
+        self.application_key = application_key
+
+        self.bucket_name_prefix = bucket_name_prefix
+
+        info = InMemoryAccountInfo()
+        cache = InMemoryCache()
+        self.api = B2Api(info, cache=cache)
+        self.api.authorize_account('production', self.account_id, self.application_key)
+
+    def create_bucket(self):
+        bucket_name = self.bucket_name_prefix + '-' + random_hex(8)
+        print('Creating bucket:', bucket_name)
+        self.api.create_bucket(bucket_name, 'allPublic')
+        print()
+        return bucket_name
+
+    def clean_buckets(self):
+        buckets = self.api.list_buckets()
+        for bucket in buckets:
+            if bucket.name.startswith(self.bucket_name_prefix):
+                print('Removing bucket:', bucket.name)
+                file_versions = bucket.ls(show_versions=True, recursive=True)
+                for file_version_info, _ in file_versions:
+                    print('Removing file version:', file_version_info.id_)
+                    self.api.delete_file_version(file_version_info.id_, file_version_info.file_name)
+
+                self.api.delete_bucket(bucket)
+                print()
+
+
+class CommandLine:
 
     EXPECTED_STDERR_PATTERNS = [
         re.compile(r'.*B/s]$', re.DOTALL),  # progress bar
         re.compile(r'^$')  # empty line
     ]
 
-    def __init__(self, command, account_id, application_key):
+    def __init__(self, command, account_id, application_key, bucket_name_prefix):
         self.command = command
         self.account_id = account_id
         self.application_key = application_key
+        self.bucket_name_prefix = bucket_name_prefix
 
     def run_command(self, args):
         """
@@ -250,6 +286,11 @@ class CommandLine(object):
             print(stdout + stderr)
             error_and_exit('did not match pattern: ' + expected_pattern)
 
+    def reauthorize(self):
+        """Clear and authorize again to the account."""
+        self.should_succeed(['clear-account'])
+        self.should_succeed(['authorize-account', self.account_id, self.application_key])
+
     def list_file_versions(self, bucket_name):
         return self.should_succeed_json(['ls', '--json', '--recursive', '--versions', bucket_name])
 
@@ -265,39 +306,6 @@ def should_equal(expected, actual):
     print()
 
 
-def delete_files_in_bucket(b2_tool, bucket_name):
-    while True:
-        files = b2_tool.should_succeed_json(['ls', '--json', '--versions', bucket_name])
-        if len(files) == 0:
-            return
-        for file_info in files:
-            b2_tool.should_succeed(
-                ['delete-file-version', file_info['fileName'], file_info['fileId']]
-            )
-
-
-def clean_buckets(b2_tool, bucket_name_prefix):
-    """
-    Removes the named bucket, if it's there.
-
-    In doing so, exercises list_buckets.
-    """
-    text = b2_tool.should_succeed(['list-buckets'])
-
-    buckets = {}
-    for line in text.split(os.linesep)[:-1]:
-        words = line.split()
-        if len(words) != 3:
-            error_and_exit('bad list_buckets line: ' + line)
-        (b_id, b_type, b_name) = words
-        buckets[b_name] = b_id
-
-    for bucket_name in buckets:
-        if bucket_name.startswith(bucket_name_prefix):
-            delete_files_in_bucket(b2_tool, bucket_name)
-            b2_tool.should_succeed(['delete-bucket', bucket_name])
-
-
 def setup_envvar_test(envvar_name, envvar_value):
     """
     Establish config for environment variable test.
@@ -351,7 +359,6 @@ def download_test(b2_tool, bucket_name):
     # there is just one file, so clean after itself for faster execution
     b2_tool.should_succeed(['delete-file-version', uploaded_a['fileName'], uploaded_a['fileId']])
     b2_tool.should_succeed(['delete-bucket', bucket_name])
-    return True
 
 
 def basic_test(b2_tool, bucket_name):
@@ -361,6 +368,11 @@ def basic_test(b2_tool, bucket_name):
 
     hex_sha1 = hashlib.sha1(read_file(file_to_upload)).hexdigest()
 
+    list_of_buckets = b2_tool.should_succeed_json(['list-buckets', '--json'])
+    should_equal(
+        [bucket_name], [b['bucketName'] for b in list_of_buckets if b['bucketName'] == bucket_name]
+    )
+
     b2_tool.should_succeed(
         ['upload-file', '--noProgress', '--quiet', bucket_name, file_to_upload, 'a']
     )
@@ -450,7 +462,7 @@ def basic_test(b2_tool, bucket_name):
 
 def key_restrictions_test(b2_tool, bucket_name):
 
-    second_bucket_name = 'test-b2-cli-' + random_hex(8)
+    second_bucket_name = b2_tool.bucket_name_prefix + '-' + random_hex(8)
     b2_tool.should_succeed(['create-bucket', second_bucket_name, 'allPublic'],)
 
     key_one_name = 'clt-testKey-01' + random_hex(6)
@@ -500,9 +512,8 @@ def key_restrictions_test(b2_tool, bucket_name):
 def account_test(b2_tool, bucket_name):
     # actually a high level operations test - we run bucket tests here since this test doesn't use it
     b2_tool.should_succeed(['delete-bucket', bucket_name])
-    new_bucket_name = bucket_name[:-8] + random_hex(
-        8
-    )  # apparently server behaves erratically when we delete a bucket and recreate it right away
+    new_bucket_name = b2_tool.bucket_name_prefix + '-' + random_hex(8)
+    # apparently server behaves erratically when we delete a bucket and recreate it right away
     b2_tool.should_succeed(['create-bucket', new_bucket_name, 'allPrivate'])
     b2_tool.should_succeed(['update-bucket', new_bucket_name, 'allPublic'])
 
@@ -516,6 +527,51 @@ def account_test(b2_tool, bucket_name):
     b2_tool.should_succeed(['authorize-account', b2_tool.account_id, b2_tool.application_key])
     tearDown_envvar_test('B2_ACCOUNT_INFO')
 
+    # Testing (B2_APPLICATION_KEY, B2_APPLICATION_KEY_ID) for commands other than authorize-account
+    new_creds = os.path.join(tempfile.gettempdir(), 'b2_account_info')
+    setup_envvar_test('B2_ACCOUNT_INFO', new_creds)
+    os.remove(new_creds)
+
+    # first, let's make sure "create-bucket" doesn't work without auth data - i.e. that the sqlite file hs been
+    # successfully removed
+    bucket_name = b2_tool.bucket_name_prefix + '-' + random_hex(8)
+    b2_tool.should_fail(
+        ['create-bucket', bucket_name, 'allPrivate'],
+        r'ERROR: Missing account data: \'NoneType\' object is not subscriptable (\(key 0\) )? '
+        r'Use: b2(\.exe)? authorize-account or provide auth data with "B2_APPLICATION_KEY_ID" and '
+        r'"B2_APPLICATION_KEY" environment variables'
+    )
+    os.remove(new_creds)
+
+    # then, let's see that auth data from env vars works
+    os.environ['B2_APPLICATION_KEY'] = os.environ['B2_TEST_APPLICATION_KEY']
+    os.environ['B2_APPLICATION_KEY_ID'] = os.environ['B2_TEST_APPLICATION_KEY_ID']
+
+    bucket_name = b2_tool.bucket_name_prefix + '-' + random_hex(8)
+    b2_tool.should_succeed(['create-bucket', bucket_name, 'allPrivate'])
+    b2_tool.should_succeed(['delete-bucket', bucket_name])
+    assert os.path.exists(new_creds), 'sqlite file not created'
+
+    os.environ.pop('B2_APPLICATION_KEY')
+    os.environ.pop('B2_APPLICATION_KEY_ID')
+
+    # last, let's see that providing only one of the env vars results in a failure
+    os.environ['B2_APPLICATION_KEY'] = os.environ['B2_TEST_APPLICATION_KEY']
+    b2_tool.should_fail(
+        ['create-bucket', bucket_name, 'allPrivate'],
+        r'Please provide both "B2_APPLICATION_KEY" and "B2_APPLICATION_KEY_ID" environment variables or none of them'
+    )
+    os.environ.pop('B2_APPLICATION_KEY')
+
+    os.environ['B2_APPLICATION_KEY_ID'] = os.environ['B2_TEST_APPLICATION_KEY_ID']
+    b2_tool.should_fail(
+        ['create-bucket', bucket_name, 'allPrivate'],
+        r'Please provide both "B2_APPLICATION_KEY" and "B2_APPLICATION_KEY_ID" environment variables or none of them'
+    )
+    os.environ.pop('B2_APPLICATION_KEY_ID')
+
+    tearDown_envvar_test('B2_ACCOUNT_INFO')
+
 
 def file_version_summary(list_of_files):
     """
@@ -536,14 +592,14 @@ def find_file_id(list_of_files, file_name):
 
 
 def sync_up_test(b2_tool, bucket_name):
-    _sync_test_using_dir(b2_tool, bucket_name, 'sync')
+    sync_up_helper(b2_tool, bucket_name, 'sync')
 
 
-def sync_test_no_prefix(b2_tool, bucket_name):
-    _sync_test_using_dir(b2_tool, bucket_name, '')
+def sync_up_test_no_prefix(b2_tool, bucket_name):
+    sync_up_helper(b2_tool, bucket_name, '')
 
 
-def _sync_test_using_dir(b2_tool, bucket_name, dir_):
+def sync_up_helper(b2_tool, bucket_name, dir_):
     sync_point_parts = [bucket_name]
     if dir_:
         sync_point_parts.append(dir_)
@@ -731,6 +787,10 @@ def sync_down_test(b2_tool, bucket_name):
     sync_down_helper(b2_tool, bucket_name, 'sync')
 
 
+def sync_down_test_no_prefix(b2_tool, bucket_name):
+    sync_down_helper(b2_tool, bucket_name, '')
+
+
 def sync_down_helper(b2_tool, bucket_name, folder_in_bucket):
 
     file_to_upload = 'README.md'
@@ -775,6 +835,52 @@ def sync_down_helper(b2_tool, bucket_name, folder_in_bucket):
         should_equal(['a', 'b', 'c'], sorted(os.listdir(local_path)))
 
 
+def sync_copy_test(b2_tool, bucket_name):
+    sync_copy_helper(b2_tool, bucket_name, 'sync')
+
+
+def sync_copy_test_no_prefix(b2_tool, bucket_name):
+    sync_copy_helper(b2_tool, bucket_name, '')
+
+
+def sync_copy_helper(b2_tool, bucket_name, folder_in_bucket):
+    file_to_upload = 'README.md'
+
+    b2_sync_point = 'b2:%s' % bucket_name
+    if folder_in_bucket:
+        b2_sync_point += '/' + folder_in_bucket
+        b2_file_prefix = folder_in_bucket + '/'
+    else:
+        b2_file_prefix = ''
+
+    other_bucket_name = b2_tool.bucket_name_prefix + '-' + random_hex(8)
+    success, _ = b2_tool.run_command(['create-bucket', other_bucket_name, 'allPublic'])
+
+    other_b2_sync_point = 'b2:%s' % other_bucket_name
+    if folder_in_bucket:
+        other_b2_sync_point += '/' + folder_in_bucket
+
+    # Put a couple files in B2
+    b2_tool.should_succeed(
+        ['upload-file', '--noProgress', bucket_name, file_to_upload, b2_file_prefix + 'a']
+    )
+    b2_tool.should_succeed(
+        ['upload-file', '--noProgress', bucket_name, file_to_upload, b2_file_prefix + 'b']
+    )
+
+    # Sync all the files
+    b2_tool.should_succeed(['sync', '--noProgress', b2_sync_point, other_b2_sync_point])
+
+    file_versions = b2_tool.list_file_versions(other_bucket_name)
+    should_equal(
+        [
+            '+ ' + b2_file_prefix + 'a',
+            '+ ' + b2_file_prefix + 'b',
+        ],
+        file_version_summary(file_versions),
+    )
+
+
 def sync_long_path_test(b2_tool, bucket_name):
     """
     test sync with very long path (overcome windows 260 character limit)
@@ -801,15 +907,18 @@ def sync_long_path_test(b2_tool, bucket_name):
         should_equal(['+ ' + long_path], file_version_summary(file_versions))
 
 
-def main():
+def main(bucket_name_prefix):
     test_map = {
         'account': account_test,
         'basic': basic_test,
         'keys': key_restrictions_test,
         'sync_down': sync_down_test,
+        'sync_down_no_prefix': sync_down_test_no_prefix,
         'sync_up': sync_up_test,
-        'sync_up_no_prefix': sync_test_no_prefix,
+        'sync_up_no_prefix': sync_up_test_no_prefix,
         'sync_long_path': sync_long_path_test,
+        'sync_copy': sync_copy_test,
+        'sync_copy_no_prefix': sync_copy_test_no_prefix,
         'download': download_test,
     }
 
@@ -818,59 +927,55 @@ def main():
     account_id = os.environ.get('B2_TEST_APPLICATION_KEY_ID', '')
     application_key = os.environ.get('B2_TEST_APPLICATION_KEY', '')
 
-    defer_cleanup = True
-    bucket_name_prefix = 'test-b2-cli-' + random_hex(8)
-
     if os.environ.get('B2_ACCOUNT_INFO') is not None:
         del os.environ['B2_ACCOUNT_INFO']
 
-    b2_tool = CommandLine(args.command, account_id, application_key)
+    b2_tool = CommandLine(args.command, account_id, application_key, bucket_name_prefix)
+    b2_api = Api(account_id, application_key, bucket_name_prefix)
 
-    global_dirty = False
     # Run each of the tests in its own empty bucket
     for test_name in args.tests:
 
         print('#')
-        print('# Cleaning and making bucket for:', test_name)
+        print('# Setup for test:', test_name)
         print('#')
         print()
 
-        b2_tool.should_succeed(['clear-account'])
-
-        b2_tool.should_succeed(['authorize-account', account_id, application_key])
-
-        if not defer_cleanup:
-            clean_buckets(b2_tool, bucket_name_prefix)
-        bucket_name = bucket_name_prefix + '-' + random_hex(8)
-
-        success, _ = b2_tool.run_command(['create-bucket', bucket_name, 'allPublic'])
-        if not success:
-            clean_buckets(b2_tool, bucket_name_prefix)
-            b2_tool.should_succeed(['create-bucket', bucket_name, 'allPublic'])
+        b2_api.clean_buckets()
+        bucket_name = b2_api.create_bucket()
 
         print('#')
         print('# Running test:', test_name)
         print('#')
         print()
 
+        b2_tool.reauthorize()  # authorization is common for all tests
         test_fcn = test_map[test_name]
-        dirty = not test_fcn(b2_tool, bucket_name)
-        global_dirty = global_dirty or dirty
+        test_fcn(b2_tool, bucket_name)
 
-    if global_dirty:
-        print('#' * 70)
         print('#')
-        print('# The last test was run, cleaning up')
+        print('# Teardown for test:', test_name)
         print('#')
-        print('#' * 70)
         print()
-        clean_buckets(b2_tool, bucket_name_prefix)
+
+        b2_api.clean_buckets()
+
     print()
     print("ALL OK")
 
 
+def cleanup_hook(application_key_id, application_key, bucket_name_prefix):
+    print()
+    print('#')
+    print('# Clean up:')
+    print('#')
+    print()
+    b2_api = Api(application_key_id, application_key, bucket_name_prefix)
+    b2_api.clean_buckets()
+
+
 # TODO: rewrite to multiple tests
-def test_integration():
+def test_integration(sut, cleanup):
     application_key_id = os.environ.get('B2_TEST_APPLICATION_KEY_ID')
     if application_key_id is None:
         pytest.fail('B2_TEST_APPLICATION_KEY_ID is not set.')
@@ -881,9 +986,15 @@ def test_integration():
 
     print()
 
-    sys.argv = ['test_b2_command_line.py']
-    main()
+    sys.argv = ['test_b2_command_line.py', '--command', sut]
+    bucket_name_prefix = 'test-b2-cli-' + random_hex(8)
+
+    if cleanup:
+        atexit.register(cleanup_hook, application_key_id, application_key, bucket_name_prefix)
+
+    main(bucket_name_prefix)
 
 
 if __name__ == '__main__':
-    main()
+    bucket_name_prefix = 'test-b2-cli'
+    main(bucket_name_prefix)
